@@ -5,7 +5,8 @@ use warnings;
 use base 'Test2::Require';
 
 # ABSTRACT: Skip a test file unless a C++ compiler is available
-our $VERSION = '0.99'; # VERSION
+our $VERSION = '1.00_01'; # TRIAL VERSION
+$VERSION = eval $VERSION;
 
 
 sub skip
@@ -28,7 +29,7 @@ Test::Alien::CanCompileCpp - Skip a test file unless a C++ compiler is available
 
 =head1 VERSION
 
-version 0.99
+version 1.00_01
 
 =head1 SYNOPSIS
 
@@ -49,7 +50,11 @@ be available.  Otherwise the test will be skipped.
 
 =head1 AUTHOR
 
-Graham Ollis <plicease@cpan.org>
+Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
+
+Contributors:
+
+Roy Storey (KIWIROY)
 
 =head1 COPYRIGHT AND LICENSE
 
